
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include "edaq530comm.h"
#include "gnuplot_i.h"

#define PLOT_LENGTH 1		//sec
#define NUM_OF_PLOTS 10
#define SAMPLING_FREQ 100


int main(int argc, char *argv[])
{
	if (argc < 3)
	{
		printf("Run program using arguments (for example /dev/ttyUSB0 voltage)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	int fd = open_edaq(argv[1]);
	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);	
	
	print_edaq_id(fd);
	
	quantity_type q_t;
	gnuplot_ctrl *h1;

	h1 = gnuplot_init() ;
	gnuplot_setstyle(h1, "lines") ;
	gnuplot_set_xlabel(h1, "Time (s)") ;

	
	if (!(strcmp(argv[2], "temp_celsius")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		q_t = temp_celsius;
		printf("Measuring thermistor result on chA\n");
		gnuplot_set_ylabel(h1, "Temperature (°C)");
	}
	else if (!(strcmp(argv[2], "temp_kelvin")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		q_t =  temp_kelvin;
		printf("Measuring thermistor result on chA\n");
		gnuplot_set_ylabel(h1, "Temperature (K)");
	}
	else if (!(strcmp(argv[2], "resistance")))
	{
		set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);
		q_t =  resistance;
		printf("Measuring resistance on chA\n");
		gnuplot_set_ylabel(h1, "Resistance (Ohm)");
	}
	else if (!(strcmp(argv[2], "voltage")))
	{
		set_inputs(fd, voltage_ch, voltage_ch, voltage_ch);
		q_t =  voltage;
		printf("Measuring voltage on chA\n");
		gnuplot_set_ylabel(h1, "Voltage (V)");
	}
	else if (!(strcmp(argv[2], "inamp")))
	{
		set_inputs(fd, inamp_ch, voltage_ch, voltage_ch);
		q_t =  voltage;
		printf("Measuring inamp on chA\n");
		gnuplot_set_ylabel(h1, "Voltage (V)");
	}
	else if (!(strcmp(argv[2], "photo")))
	{
		set_inputs(fd, photo_ch, voltage_ch, voltage_ch);
		q_t =  voltage;
		printf("Measuring photo on chA\n");
		gnuplot_set_ylabel(h1, "Voltage (V)");
	}
	else
	{
		printf("Invalid argument %s. Valid arguments are: voltage, resistance, temp_kelvin, temp_celsius, inamp, photo. The program now exit...\n", argv[2]);
		exit(EXIT_FAILURE);
	}
	
	unsigned char c='D';
	int data_count = SAMPLING_FREQ * PLOT_LENGTH;
	
	int data[data_count];

	set_sampling_freq(fd, SAMPLING_FREQ);
	
	double result[data_count];
	double x[data_count];
	int i, j;
	
	for (i = 0; i < data_count; i++)
		x[i] = (float)i / SAMPLING_FREQ;
	
	//    
    	start_cont_sampling(fd);
    	for (i = 0; i < NUM_OF_PLOTS; i++)
	{
		fill_array_cont_sampling(fd, data, data_count);
		gnuplot_resetplot(h1) ;
		for (j = 0; j < data_count; j++)
		{
			result[j] = get_measured_quantity(data[j], temp_celsius);
		}
		
  		
  		gnuplot_plot_xy(h1, x, result, data_count, "");

	}
	
	
	stop_cont_sampling(fd);
	
	gnuplot_close(h1) ;
	close(fd);
	return 0;
}
