#include <gtk/gtk.h>
#include<gdk-pixbuf/gdk-pixbuf.h>
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <malloc.h>
#include "edaq530comm.h"

#define PERIOD_MS 500

typedef struct temperature_data{
	int fd;
	GtkLabel *label;
} temperature_data;

static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
{
	return FALSE;
}

static void destroy(GtkWidget *widget, gpointer data)
{
	close(*(int* ) data);	
	gtk_main_quit();
}

gint measure_temperature(gpointer data)
{
	int meas[3];
	measure_edaq(((temperature_data* )data)->fd, meas);
	float temp = get_measured_quantity(meas[0], temp_celsius);

	gchar* buf;
	buf = g_strdup_printf("<span font_desc=\"32.0\">%.2f °C</span>", temp);
	gtk_label_set_markup(((temperature_data* )data)->label, buf);
	g_free(buf);
	return TRUE;
}

int main( int argc, char *argv[] )
{
	if (argc < 2)
	{
		printf("Run program using argument (for example /dev/ttyUSB0)! The program now exit...\n");
		exit(EXIT_FAILURE);
	}
	unsigned char c='D';
	int fd = open_edaq(argv[1]);

	if(fd == -1)
	{
		printf("Failed to open %s! The program now exit...\n", argv[1]);
		exit(EXIT_FAILURE);
	}
	printf("%s is opened\n", argv[1]);	
	print_edaq_id(fd);
	set_inputs(fd, resistor_ch, voltage_ch, voltage_ch);

	//GTK
	GtkWidget *window;
	GtkWidget *label;
    
	gtk_init(&argc, &argv);
    	
	//window
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(window), "Temperature");
	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file("./icon/plet_icon2.png", NULL);
	gtk_window_set_icon(GTK_WINDOW(window), pixbuf);
	g_signal_connect(window, "delete_event", G_CALLBACK(delete_event), NULL);
	g_signal_connect(window, "destroy", G_CALLBACK(destroy), &fd);	
	//g_signal_connect(window, "destroy", G_CALLBACK(destroy), NULL);
	gtk_container_set_border_width(GTK_CONTAINER(window), 10);

	//label
	label = gtk_label_new("");
	temperature_data *temp_data;
	temp_data = malloc (sizeof(temperature_data)); 
	temp_data->fd = fd;
	temp_data->label = (GtkLabel *) label;
	
	gtk_widget_set_size_request(label, 250, 150);
	gtk_container_add(GTK_CONTAINER(window), label);
	
	g_timeout_add(PERIOD_MS, measure_temperature, temp_data);
	gtk_widget_show(label);
	gtk_widget_show(window);
	
    
	gtk_main();
    
	return 0;
}
